@@ -74,7 +74,7 @@ our %var_def;
 our %var_use;
 
 require Exporter;
-our @ISA = 'Exporter';
+our @ISA = qw(Exporter);
 my @most = qw(redefined forget rebuild callers callees
 	      var_defs var_uses
 	      var_apropos);
@@ -116,8 +116,6 @@ my %code = (intro => "i", used => "",
 	    formdef => "f", meth => "->");
 
 
-=head2 Functions
-
 =item C<guess_module_file($pack, $ofile)>
 
 XXX: it turns out that rooting around trying to figure out the file
@@ -259,14 +257,6 @@ sub load_pad {
 	    next unless class($valsv) eq "GV";
 	    # these pad GVs don't have corresponding names, so same @pad
 	    # array can be used without collisions
-
-            # XXX: for some reason, on 5.10 $valsv->STASH can be a
-            # B::SPECIAL, which doesn't have a name.
-
-            # XXX: this segfaults on 5.10 for some reason while
-            # traversing File::Find::contract_name from main
-
-            next if ref $valsv->STASH eq 'B::SPECIAL';
 	    $pad[$ix] = [$valsv->STASH->NAME, "*", $valsv->NAME];
 	}
     }
@@ -295,6 +285,7 @@ sub xref {
 	    xref($op->pmreplstart);
 	} else {
 	    no strict 'refs';
+#             print STDERR $opname;
 	    my $ppname = "pp_$opname";
 	    &$ppname($op) if defined(&$ppname);
 	}
@@ -500,6 +491,10 @@ sub xref_definitions {
     walksymtable(\%{"main::"}, "xref", sub { !xref_exclude($_[0]) });
 }
 
+=head2 Functions
+
+=over
+
 =item C<rebuild()>
 
 Rebuild the Xref database.
@@ -679,13 +674,10 @@ List the modules defined in file C<$file>.
 
 sub file_modules {
     my $file = shift;
-    eval {
-        require Module::Info;
-        my $mod = Module::Info->new_from_file(abs_path($file));
-        if ( $mod ) {
-            return $mod->packages_inside();
-        }
-    }
+    eval "use Module::Include;" and do {
+        my $mod = Module::Include->new_from_file(abs_path($file));
+        return ($mod && $mod->packages_inside) || undef;
+    };
 }
 
 =item C<var_apropos($expr)>
